#!/usr/bin/ksh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# Restarts the the various services as denoted by the given agent type.
#
# @param
#	agent_type=<common, platform>
#			Common Agent or Platform Agent.
#
#
# @return
#	result=success
#			Overall operation succeed. No errors returned by the start command
#
#	result=fail
#			in case the services fail to start
#
#	result=notfound
#			in case the scripts are missing
#
#---------------------------------------------------------------------------

#---------------------------------------------------------------------------
# Utility function to wait for the specified subsystem to stop.
#
#	@param susbsystem service name
#	@return 0 subsystem reported as stopped during the predefined elapsed 
#	time
#	@return 1 subsystem not being reported stopped during the predefined
#	elapsed time
#
#---------------------------------------------------------------------------
function wait_for_service_to_stop {
	
	for i in 1 2 3 4 5 6 7 8 9 10
	do
		sleep 10
		/usr/bin/lssrc -s $1 | grep -i inoperative  >/dev/null 2>&1
		res=$?
		if [ "$res" = "0" ]; then
			break
		else
			echo "dummy" > /dev/null
		fi
		if [ "$i" = "10" ]; then
			return 1
		fi
	done
	
	return 0
}


agent_type="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

if [[ ! -a /usr/bin/stopsrc ]] 
	then goto COMMON_MISSING_ERR
fi

if [[ ! -a /usr/bin/startsrc ]] 
	then goto COMMON_MISSING_ERR
fi

# -----------------------------------------------
# SLP common to both platform and common agents
# Kill it to ensure it is not running and will 
# start from fresh when starting platform_agent
# subsystem
# -----------------------------------------------
slp_pid="$(ps -ef | grep slp_srvreg | grep -v grep | awk '{print $2}' )"
if [ "x$slp_pid" != "x" ]; then
	kill -9 $slp_pid >/dev/null 2>&1
fi

if [ "$agent_type" = "platform" ]; then
	/usr/bin/stopsrc -s platform_agent >/dev/null 2>&1
	wait_for_service_to_stop "platform_agent"
	RC=$?
	if [ "$RC" != "0" ]; then
        echo "result=fail,platform_agent_RC=stop_fail"
        exit 0;
	fi
		
	/usr/bin/stopsrc -s cimsys	>/dev/null 2>&1
	wait_for_service_to_stop "cimsys"
	RC=$?
		if [ "$RC" != "0" ]; then
        echo "result=fail,cimserver_RC=stop_fail"
        exit 0;
	fi
	
	/usr/bin/startsrc -s platform_agent >/dev/null 2>&1
	RC=$?

	if [ "$RC" != "0" ]; then
        echo "result=fail"
        exit 0;
	fi
else 
	/usr/bin/stopsrc -s platform_agent >/dev/null 2>&1
	wait_for_service_to_stop "platform_agent"
	RC=$?
	if [ "$RC" != "0" ]; then
        echo "result=fail,platform_agent_RC=stop_fail"
        exit 0;
	fi
	
	/usr/bin/stopsrc -s cimsys >/dev/null 2>&1
	wait_for_service_to_stop "cimsys"
	RC=$?
		if [ "$RC" != "0" ]; then
        echo "result=fail,cimserver_RC=stop_fail"
        exit 0;
	fi
	
	/usr/bin/startsrc -s platform_agent >/dev/null 2>&1
	RC=$?

	if [ "$RC" != "0" ]; then
        echo "result=fail"
        exit 0;
	fi	
	
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh stop >/dev/null 2>&1
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh status | grep Subsystem >/dev/null 2>&1
	RC=$?
	if [ "$RC" = "0" ]; then
		# ---------------------------------------------------
		# This endpoint.sh status uses the new status format
		# (subsystem status) so wait till being stopped
		# ---------------------------------------------------
		wait_for_service_to_stop "cas_agent"
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail,common_RC=stop_fail"
        	exit 0;
		fi
	fi	
	
	/opt/ibm/director/agent/runtime/agent/bin/endpoint.sh start >/dev/null 2>&1
	RC=$?

	if [ "$RC" != "0" ]; then
        echo "result=fail"
        exit 0;
	fi
fi

echo "result=success"
exit 0

:COMMON_MISSING_ERR
echo "result=notfound"
exit 0
