#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# Retrieves UID and Tivoli GUID keys from the endpoint.
#
# @return
#	result=success
#			Overall operation succeed. Additional info might be 
#			set in keys.
#
#	result=fail
#			Overall operation failed.
#
#	twg_uid={<twgagent.uid>, notfound}
#			The key. 
#			notfound in case key not found
#
#	tivoli_guid={<tivoli_guid>, notfound}
#			The key. 
#			notfound in case key not found
#
# ---------------------------------------------------------------------------

uid=notfound
guid=notfound

# -----------------------------------------------
# Do we indeed have a uid file to read from ?
# -----------------------------------------------
if [ -f /etc/ibm/director/twgagent/twgagent.uid ];then
	# -----------------------------------------------
	# At first, verify that utility exists and that it 
	# properly works. Then, invoke it once again and 
	# capture first line only
	# -----------------------------------------------
	if [ -x /usr/bin/od ];then
		/usr/bin/od -t x1 /etc/ibm/director/twgagent/twgagent.uid > /dev/null 2>&1
		RC=$?
		if [ "$RC" != "0" ]; then
        	echo "result=fail"
        	exit 0;
		fi
		
		# -----------------------------------------------
		# We reply on the fact that UID length is always
		# 8 pairs splited with space
		# -----------------------------------------------
		uid="$(/usr/bin/od -t x1 /etc/ibm/director/twgagent/twgagent.uid | grep 0000000 | awk '{ print $2$3$4$5$6$7$8$9 }')"
	fi
fi

# -----------------------------------------------
# Do we indeed have a tivoli guid utility to use ?
# -----------------------------------------------
if [ -x /opt/tivoli/guid/tivguid ];then
	# -----------------------------------------------
	# At first, verify that utility exists and that it 
	# properly works. Then, invoke it once again 
	# along with awk to capture tivoli guid
	# -----------------------------------------------
	/opt/tivoli/guid/tivguid -Show > /dev/null 2>&1
	RC=$?
	if [ "$RC" != "0" ]; then
		echo "result=fail"
		exit 0;
	fi
	LANG=C
	guid="$(/opt/tivoli/guid/tivguid -Show | grep Guid | awk '{ {split($1, split_result, ":")} {print split_result[2]} }' | awk '{ {split($1, split_result, ".")} {print split_result[1]split_result[2]split_result[3]split_result[4]split_result[5]split_result[6]split_result[7]split_result[8]split_result[9]split_result[10]split_result[11]split_result[12]split_result[13]split_result[14]split_result[15]split_result[16] } }')"
fi

echo "result=success,twg_uid=$uid,tivoli_guid=$guid"
