#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# --------------------------------------------------------------------------
# Resets UID and Tivoli GUID keys on the endpoint.
#
# @return
#	result=success
#			Overall operation succeed.
#
#	result=fail
#			Overall operation failed. More details given in ssh_RC below.
#
#	uid_RC=key_gen_fail
#			A failure occurred while re-generating UID key
#
#	tivguid_RC=key_gen_fail
#			A failure occurred while re-generating Tivoli GUID key
#
# ---------------------------------------------------------------------------


# -----------------------------------------------
# Generate new UID
# -----------------------------------------------
if [ -f /etc/ibm/director/twgagent/twgagent.uid ];then
	/bin/rm -f /etc/ibm/director/twgagent/twgagent.uid
fi

if [ -x /opt/ibm/platform/bin/genuid ];then
	/opt/ibm/platform/bin/genuid >/dev/null 2>&1
	RC=$?
	if [ "$RC" != "0" ]; then
		echo "result=fail,uid_RC=key_gen_fail"
		exit 0
	fi
fi

# -----------------------------------------------
# Generate new tivguid
# -----------------------------------------------
if [ -x /opt/tivoli/guid/tivguid ];then
	LANG=C;
	/opt/tivoli/guid/tivguid -Write -New >/dev/null 2>&1
	RC=$?
	if [ "$RC" != "0" ]; then
		echo "result=fail,tivguid_RC=key_gen_fail"
		exit 0
	fi
	
fi

echo "result=success"
