#! /bin/bash
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

# -----------------------------------------------------------------------
# Reports whether Director server's resource manager can correctly 
# interact with its Agent Manager (by querying, for example, its 
# registered agents).
#
# @param
#	user=<DS user>
#	password=<DS password>
#
# @return
#
#	result=fail_auth
#				Failed to invoke smcli with DS credentials supplied.
#
#	result=fail 
#				In case a failure occurred while interacting with 
#				Agent Manager. Note: we currently report 'fail' in case we 
#				did not receive any agent. The local MEP CAS agent must be
#				returned and if not, then there must be some issue..
#	
#	result=success
#				In case a successful interaction occurred with 
#				Agent Manager. Note: we report 'success' in case we 
#				receive at least one agent. The local MEP CAS agent must be
#				returned.
#
# ------------------------------------------------------------------------
user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# First time just to check error code with i/o redirection
smcli -user $user -pw $password getDefaultAgentManager > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

smcli -user $user -pw $password queryAllAgentsByAM > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

# ---------------------------------------------
# First, retrieve the default agent manager
# ID.
# ---------------------------------------------
default_am_id="$(smcli -user $user -pw $password getDefaultAgentManager | awk '{ {split($0, split_result, ":")} {print split_result[2]} }')"
default_am_id_no_spaces=${default_am_id/ /}

# ---------------------------------------------------------------
# queryAllAgentsByAM, prints a line which starts with a single
# word only -- "Agent", in case there is at least one agent to output.
# Otherwise, some error will be printed which WILL NOT start with
# the word "Agent", or nothing will be printed.
# 
# We pass the entire output to awk so it can output the first word 
# ($1) of every line. Then we want to retrieve the first occurance
# of "Agent" so we use the grep
# ---------------------------------------------------------------

agent_line="$(smcli -user $user -pw $password queryAllAgentsByAM $default_am_id_no_spaces | awk '{ {print $1} }' | grep -m 1 -w "Agent")"

case "$agent_line" in
    *Agent* ) echo "result=success"; exit 0;;
    * ) echo "result=fail";;
esac
