@echo off
REM Licensed Materials - Property of IBM
REM
REM (C) Copyright IBM Corp. 2013 All Rights Reserved
REM
REM US Government Users Restricted Rights - Use, duplicate or
REM disclosure restricted by GSA ADP Schedule Contract with
REM IBM Corp.

rem --------------------------------------------------------------------------
rem Verifies the status of the various services needed by the given 
rem agent type.
rem
rem @param
rem	agent_type=<common, platform>
rem			Common Agent or Platform Agent.
rem			The following services will be checked for Common Agent:
rem			1. slp daemon
rem			2. common agent process
rem
rem			The following services will be checked for Platform Agent:
rem			1. slp daemon
rem			2. cimlistener
rem			3. cimserver
rem			4. tier1slp
rem
rem
rem @return
rem	result=success
rem			Overall operation succeed. Detailed status is given by the 
rem			<service_RC> keys.
rem
rem	slp_RC={success, fail, notfound}
rem	common_RC={success, fail, notfound}
rem	cimlistener_RC={success, fail, notfound}
rem	cimserver_RC={success, fail, notfound}
rem	tier1slp_RC={success, fail, notfound}
rem
rem	result=fail
rem			Overall operation failed (wrong commands, the command
rem			to evaluate failed or the command was not found.
rem
rem ---------------------------------------------------------------------------

set agent_type=%2

rem -----------------------------------------------
rem SLP common to both platform and common agents
rem -----------------------------------------------
for /f "tokens=1,2,3" %%a in ('net start ^| find "IBM SLP SA"') do (
   
   	if "%%a"=="IBM" (
   			if "%%b"=="SLP" (
   					if "%%c"=="SA" (
   						set slp_RC=slp_RC=success
   						goto CHECK_PLATFORM
   					)
	  	 		rem "SLP"
	  	 		)
	rem "IBM"
	)

rem FOR
)

set slp_RC=slp_RC=fail

:CHECK_PLATFORM

rem -----------------------------------------------
rem Platform Agent specific service
rem -----------------------------------------------

if "%agent_type%"=="platform" (

	for /f "tokens=1,2,3,4" %%a in ('net start ^| find "IBM CIM Listener Service"') do (
   		if "%%a" == "IBM" (
   				if "%%b" == "CIM" (
   						if "%%c" == "Listener" (
   							if "%%d" == "Service" (
   							set cimlistener_RC=cimlistener_RC=success
   							goto CHECK_PLATFORM2
   							)
   						
   						rem "Listener"
   						)
	  	 			rem "CIM"
	  	 			)
		rem "IBM"
		)

	rem FOR
	)

	set cimlistener_RC=cimlistener_RC=fail

)

:CHECK_PLATFORM2

rem -----------------------------------------------
rem Platform Agent specific service
rem -----------------------------------------------

if "%agent_type%"=="platform" (

	for /f "tokens=1,2,3" %%a in ('net start ^| find "IBM WMI+A Service"') do (
   
   		if "%%a" == "IBM" (
   				if "%%b" == "WMI+A" (
   						if "%%c" == "Service" (
   							set cimserver_RC=cimserver_RC=success
   							goto CHECK_PLATFORM3
   						)
	  	 			rem "WMI+A"
	  	 			)
		rem "IBM"
		)

	rem FOR
	)

	set cimserver_RC=cimserver_RC=fail
 
)

:CHECK_PLATFORM3

rem -----------------------------------------------
rem Platform Agent specific service
rem -----------------------------------------------

if "%agent_type%"=="platform" (

	for /f "tokens=1,2,3,4" %%a in ('net start ^| find "IBM SLP Attributes Service"') do (
	   	if "%%a" == "IBM" (
 	  			if "%%b" == "SLP" (
 	  					if "%%c" == "Attributes" (
  	 						if "%%d" == "Service" (
  	 						set tier1slp_RC=tier1slp_RC=success
  	 						goto CHECK_COMMON
   							)
   						
   						rem "Attributes"
   						)
		  	 		rem "SLP"
		  	 		)
		rem "IBM"
		)

	rem FOR
	)

	set tier1slp_RC=tier1slp_RC=fail

rem "platform"
)

:CHECK_COMMON

rem -----------------------------------------------
rem Common Agent specific service
rem -----------------------------------------------

if "%agent_type%" == "common" (

	for /f "tokens=1,2,3" %%a in ('net start ^| find "Tivoli Common Agent"') do (
    
    	if "%%a" == "Tivoli" (
    			if "%%b" == "Common" (
    					if "%%c" == "Agent" (
    						set common_RC=common_RC=success
    						goto FINALLY
    					)
 	  	 		)
		)
	
	rem FOR
	)
	
	set common_RC=common_RC=fail

rem "common"
)

:FINALLY

rem ---------------------------------------------------------
rem We were able to grab the services status so output them
rem ---------------------------------------------------------

if "%agent_type%" == "common" (

	echo result=success,%slp_RC%,%common_RC%

)

if "%agent_type%" == "platform" (

	echo result=success,%slp_RC%,%cimlistener_RC%,%cimserver_RC%,%tier1slp_RC%
)

exit /b 0
